@@ -27,7 +27,7 @@ def sagemaker_training_run(
     if not script.startswith(source):
         raise ValueError("script=[{}] must be in source=[{}]")
     entry_point = script[len(source)+1:]
-    entry_point = entry_point.replace("\\","/")
+    entry_point = entry_point.replace("\\", "/")
     metric_definitions = [
         {'Name': k, 'Regex': v}
         for k, v in metrics.items()
@@ -45,6 +45,8 @@ def sagemaker_training_run(
     iam = session.boto_session.client('iam')
     training_role = ensure_training_role(
         iam=iam, role_name=args.sagemaker_training_role)
+    hyperparameters = {k: str(v)
+                       for k, v in vars(args).items() if len(str(v)) > 0}
     estimator = PyTorch(
         sagemaker_session=session,
         base_job_name=args.sagemaker_base_job_name,
@@ -59,7 +61,9 @@ def sagemaker_training_run(
         metric_definitions=metric_definitions,
         dependencies=dependencies,
         # checkpoint_s3_uri=checkpoint_s3_uri,
-        checkpoint_local_path=CHECKPOINT_LOCAL_PATH
+        checkpoint_local_path=CHECKPOINT_LOCAL_PATH,
+        use_spot_instances=args.sagemaker_spot_instances,
+        hyperparameters=hyperparameters
     )
 
     channels = config.channels
@@ -75,10 +79,12 @@ def sagemaker_training_run(
             experiment_config["TrialName"] = args.sagemaker_trial_name
     else:
         if args.sagemaker_trial_name:
-            raise ValueError("If `sagemaker_trial_name` is provided, `sagemaker_experiment_name` must be provided as well")
+            raise ValueError(
+                "If `sagemaker_trial_name` is provided, `sagemaker_experiment_name` must be provided as well")
         experiment_config = None
 
-    estimator.fit(channels, job_name=job_name, wait=args.sagemaker_wait, experiment_config=experiment_config)
+    estimator.fit(channels, job_name=job_name,
+                  wait=args.sagemaker_wait, experiment_config=experiment_config)
     # todo:
     # use_spot_instances
     # experiment_config (dict[str, str]): Experiment management configuration.
